{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "bc077a0d-3cac-4f63-8b00-fa6d878fe2a7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "hide-cell"
    ]
   },
   "outputs": [],
   "source": [
    "from vega import Vega\n",
    "import altair as alt\n",
    "import numpy as np\n",
    "\n",
    "import pandas as pd\n",
    "institutions_df = pd.read_csv(\"institution-totals.csv\")\n",
    "\n",
    "regional_institutions_df = institutions_df.query('sector == \"regional\"')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "da9d64f3-2654-48e4-b31d-f42f260f535c",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "# Regional Institutions Overview"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "eb26e498-3320-4d0d-b76a-083d47f66391",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-width"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-f340af1eb72b45b391bb5cc51539e97e.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-f340af1eb72b45b391bb5cc51539e97e.vega-embed details,\n",
       "  #altair-viz-f340af1eb72b45b391bb5cc51539e97e.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-f340af1eb72b45b391bb5cc51539e97e\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-f340af1eb72b45b391bb5cc51539e97e\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-f340af1eb72b45b391bb5cc51539e97e\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"vconcat\": [{\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Aberdeen Archives, Gallery and Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Aberdeen Archives, Gallery and Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 247327\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-8f50f02c680b4fa5162b5b2d4d5b0cae\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Aberdeen Archives, Gallery and Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Aberdeenshire Council Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Aberdeenshire Council Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 250000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-a0c3a5906202575e7b0edb3dafb3606d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Aberdeenshire Council Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Auchindrain Historic Township\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Auchindrain Historic Township\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-b5b5474dfa8a4af47695f5830e023882\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Auchindrain Historic Township\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Barnsley Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Barnsley Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 711400\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-d5357a5e1134bd5f6e58dc69a328a6e3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Barnsley Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Beamish Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Beamish Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-b916638082d972f147a9303a3313a32d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Beamish Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Birmingham Museums Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Birmingham Museums Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 800000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 800000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-f5bfe9f58793a903e05c2a65b2156071\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Birmingham Museums Trust\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Black Country Living Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Black Country Living Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0.10809087499999999, \"tooltip\": \"Catalogued Artefacts: 4903\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.128090875, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 80000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.1980908749999997, \"tooltip\": \"Catalogued Objects: 4903\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.2180908749999997, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 80000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-d9d03407b1f46b1f3f1c51fa5f951392\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Black Country Living Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Bradford District Museums & Galleries\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Bradford District Museums & Galleries\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 837837\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 387837\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-76dcec2fb5eaae1d7b013590cf76ba41\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Bradford District Museums & Galleries\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Bristol Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Bristol Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 2000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-2a0dd31c67900b8070beaebb78d8ed2e\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Bristol Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Colchester and Ipswich Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Colchester and Ipswich Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 220000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-9b4a1e706b01e369125107582239caf3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Colchester and Ipswich Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Coventry\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Coventry\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0.9122444999999999, \"tooltip\": \"Catalogued Artefacts: 446050\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.9322444999999999, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Catalogued Objects: 109173\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-785b146f8faa7252899718eea5a3893d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Culture Coventry\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Perth and Kinross\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Perth and Kinross\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 500000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-bb8d23a10e4d46a68b6317edd7813d7c\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Culture Perth and Kinross\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Trust Luton\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Culture Trust Luton\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1105051\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 5051\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-915302f4cc4f0ea05e09ed3fde6ddeea\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Culture Trust Luton\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Derby Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Derby Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-ede38ab306edd12d80552566f6f4576a\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Derby Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Dumfries and Galloway Council Arts and Museums Service\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Dumfries and Galloway Council Arts and Museums Service\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-65e09163c56d04c0818fc27644e7dfcf\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Dumfries and Galloway Council Arts and Museums Service\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Dundee Heritage Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Dundee Heritage Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-5f93e30645560c866e30c0ed3b6a1335\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Dundee Heritage Trust\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"East Ayrshire Leisure Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"East Ayrshire Leisure Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-dbc54208696341a279acda1094e987fe\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"East Ayrshire Leisure Trust\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Edinburgh Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Edinburgh Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 220000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 220000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-3621cd5bbd9933a31dd224c77d865e5c\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Edinburgh Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Elgin Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Elgin Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 36000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 36000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-58a3bbdf2d67d395336cc984ab673f78\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Elgin Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Glasgow Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Glasgow Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-093b37d40df86d7edfa2ce9bc8e9c833\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Glasgow Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Groam House Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Groam House Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-be6955d47adc1b72c040cda41fddb9af\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Groam House Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Heritage Doncaster\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Heritage Doncaster\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 406750\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 405000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-c60b3848499adfefb039b887a47bc190\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Heritage Doncaster\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Highland Folk Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Highland Folk Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 10000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 10000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-0d22b11ffac65d9ebbfd3e1621dc454d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Highland Folk Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Hull Museums Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Hull Museums Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-384f9cbe2052f29e2114dfe6b4491606\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Hull Museums Collections\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leeds Museums & Galleries\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leeds Museums & Galleries\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1300000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 1300000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-947628e383266059d87eef2445a20906\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Leeds Museums & Galleries\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leicester Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leicester Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1500000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 1500000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-71a94014dd597d52fc4a6c14164e098b\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Leicester Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leicestershire County Council Museum Servive\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Leicestershire County Council Museum Servive\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-443c19814bc117562decfaa958bc9c91\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Leicestershire County Council Museum Servive\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Liverpool Record Office\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Liverpool Record Office\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-1f9377a945d0ca94efa301726735c476\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Liverpool Record Office\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Manchester Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Manchester Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 50000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 50000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-2d7da1f275b69cdd2d19748e543d119e\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Manchester Art Gallery\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Museums Northhumberland\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Museums Northhumberland\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 25000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 25000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-97029f92aa31b40a8ea6f121b240981c\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Museums Northhumberland\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Norfolk Museums Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Norfolk Museums Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-a1c0f229e6da03da709fedc3bb6838c3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Norfolk Museums Collections\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Northern Ireland Screen\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Northern Ireland Screen\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 47\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-484fff9710d8c12db84937de628207e9\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Northern Ireland Screen\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Northhampton Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Northhampton Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 44024\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 44024\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-ba7d2f6d2013323968538aa6dc8a244d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Northhampton Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Orkney Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Orkney Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 100000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-b729f1bec6e2f7b6276caa02967cb4de\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Orkney Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Poole Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Poole Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0.04224019999999999, \"tooltip\": \"Catalogued Artefacts: 1489\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.062240199999999996, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 50000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.1322402, \"tooltip\": \"Catalogued Objects: 1489\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.1522402, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 50000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-828d08fa9ee5059dc48e2bd092adbc76\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Poole Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Potteries Museum and Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Potteries Museum and Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": -0.01688799, \"tooltip\": \"Catalogued Artefacts: 1489\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.00311201, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.07311201, \"tooltip\": \"Catalogued Objects: 1489\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09311201, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-235c8cb6ef3356c26a1a6d9e7dc6848e\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Potteries Museum and Art Gallery\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Preston Park Museum & Grounds\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Preston Park Museum & Grounds\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 100000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 100000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-110567b3995a8bc6bbc9bfb7ff145ef8\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Preston Park Museum & Grounds\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Ripon Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Ripon Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": -0.015355555555555556, \"tooltip\": \"Catalogued Artefacts: 20\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.004644444444444444, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 9000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.0734833333333333, \"tooltip\": \"Catalogued Objects: 15\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.0934833333333334, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 9000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-eefda7e81b8ac4195cafc4a1aaea1bc6\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Ripon Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Royal Albert Memorial Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Royal Albert Memorial Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0.013439999999999997, \"tooltip\": \"Catalogued Artefacts: 16000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0.03344, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-74aa0f112b2d1a1baaf40e45a380e746\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Royal Albert Memorial Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Salisbury Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Salisbury Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 100000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 100000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-a5aaaa265e3df665d51be45d156a2a48\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Salisbury Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Sheffield Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Sheffield Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 1000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-dc07f8c4788c74b8ff03a80bf17d88a3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Sheffield Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Southampton Cultural Services\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Southampton Cultural Services\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-d459015b366d2fe7a456263e23487587\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Southampton Cultural Services\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"St Helens Borough Council\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"St Helens Borough Council\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-9a9ef6422b470d5696178918f738c0e3\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"St Helens Borough Council\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Staffordshire Archive and Heritage\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Staffordshire Archive and Heritage\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-d9ada58a94eeaadd9ce6687c07c4749e\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Staffordshire Archive and Heritage\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Sunderland Museum & Winter Gardens' Collection\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Sunderland Museum & Winter Gardens' Collection\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 108000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-2bc0a552153b8512b0caf22caca6c86f\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Sunderland Museum & Winter Gardens' Collection\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Thackray Museum of Medicine\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Thackray Museum of Medicine\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 75000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-80f313c6a69783561cd00b6653936944\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Thackray Museum of Medicine\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"The Box Plymouth\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"The Box Plymouth\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 21691\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-5049faf841d297c7e57c4b180dc2d53d\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"The Box Plymouth\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Tuillie House Museum and Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Tuillie House Museum and Art Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 1000000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-2a00d8a208e7b67639d2227c559ee6c7\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Tuillie House Museum and Art Gallery\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Tyne & Wear Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Tyne & Wear Museums\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 490107\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-f1ac0355d9fd1e5f5117e0aadc01e6c8\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Tyne & Wear Museums\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Vindolanda Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Vindolanda Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-a78afe279d1bcb712a267e97983cc715\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Vindolanda Trust\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wakefield Museums and Castles Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wakefield Museums and Castles Collections\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 111000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 111000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-73cd7e6866fce1000c26a4de461041e1\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Wakefield Museums and Castles Collections\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Watts Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Watts Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 12541\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-f733beb95f73991a41f2f8b7ee97ea83\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Watts Gallery\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Weald and Downland Living Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Weald and Downland Living Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 15000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 15000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-573e8c930b90032a01373ee701ad0eae\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Weald and Downland Living Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"William Morris Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"William Morris Gallery\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 10000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#fd8d3c\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 10000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-147d310e2f3cfa938fe98e5f75acee5e\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"William Morris Gallery\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wiltshire Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wiltshire Museum\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"gold\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Catalogued Artefacts: 126410\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-fdec4411ade052e269e7eaa77eae6250\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Wiltshire Museum\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}, {\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wordsworth Museum Collection\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"Wordsworth Museum Collection\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"#9ecae1\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 68000\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-9bb7dd6cba5e392e8a34c99026b2d188\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"Wordsworth Museum Collection\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}, {\"hconcat\": [{\"vconcat\": [{\"layer\": [{\"mark\": {\"type\": \"arc\", \"cornerRadius\": 5, \"innerRadius\": 45, \"outerRadius\": 60, \"stroke\": \"#fff\"}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"York Museums Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"text\", \"radiusOffset\": 58}, \"encoding\": {\"color\": {\"field\": \"labels\", \"legend\": {\"orient\": \"top\", \"titleOrient\": \"left\"}, \"scale\": {\"scheme\": \"category20c\"}, \"sort\": \"ascending\", \"type\": \"nominal\"}, \"radius\": {\"field\": \"values\", \"scale\": {\"type\": \"sqrt\", \"zero\": true, \"rangeMin\": 20}, \"type\": \"quantitative\"}, \"text\": {\"condition\": {\"test\": {\"field\": \"values\", \"gt\": 0}, \"field\": \"values\", \"type\": \"quantitative\"}, \"value\": \"\"}, \"theta\": {\"field\": \"values\", \"stack\": true, \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"labels\", \"type\": \"nominal\"}}, \"title\": {\"text\": \"York Museums Trust\", \"anchor\": \"middle\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 0}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 0, \"theta2\": 2.07, \"tooltip\": \"Total Artefacts: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 2.09}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 2.09, \"theta2\": 4.16, \"tooltip\": \"Total Objects: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 6.27, \"tooltip\": \"Total Library Items: 0\"}}, {\"mark\": {\"type\": \"arc\", \"color\": \"grey\", \"innerRadius\": 90, \"outerRadius\": 100, \"theta\": 4.18, \"theta2\": 4.18}}], \"data\": {\"name\": \"data-8efa0851e692b95effe838febd00f85b\"}, \"height\": 200, \"width\": 200}, {\"data\": {\"name\": \"data-21a7ac413dad29783663de33d8782127\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": {\"field\": \"institution\", \"oneOf\": [\"York Museums Trust\"]}, \"value\": \"gold\"}, \"value\": \"white\"}, \"tooltip\": {\"field\": \"artefacts\", \"type\": \"quantitative\"}, \"x\": {\"field\": \"artefacts\", \"title\": \"Proportion of National Collection\", \"type\": \"quantitative\"}}, \"height\": 20, \"width\": 200}], \"resolve\": {\"scale\": {\"theta\": \"independent\"}}}], \"resolve\": {\"scale\": {\"theta\": \"shared\"}}, \"spacing\": 40}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-8f50f02c680b4fa5162b5b2d4d5b0cae\": [{\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 247327, \"calculated\": 247327, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 0, \"calculated\": 247327, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 151529, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"values\": 95798, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-21a7ac413dad29783663de33d8782127\": [{\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"artefacts\": 50000, \"objects\": 50000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"artefacts\": 10000, \"objects\": 10000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Colchester and Ipswich Museums\", \"sector\": \"regional\", \"artefacts\": 220000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 220000, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"artefacts\": 75000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"artefacts\": 1000000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Vindolanda Trust\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Watts Gallery\", \"sector\": \"regional\", \"artefacts\": 12541, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 7756, \"library_records\": 4117, \"archive_records\": 668}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"artefacts\": 68000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"sector\": \"regional\", \"artefacts\": 247327, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 151529, \"library_records\": 0, \"archive_records\": 95798}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"artefacts\": 250000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"artefacts\": 711400, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Auchindrain Historic Township\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Beamish Museum\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"artefacts\": 800000, \"objects\": 800000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"artefacts\": 80000, \"objects\": 80000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 4903, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"The Box Plymouth\", \"sector\": \"regional\", \"artefacts\": 21691, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 21691, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"artefacts\": 837837, \"objects\": 387837, \"library_items\": 0, \"archive_items\": 450000, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"artefacts\": 2000000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"artefacts\": 1000000, \"objects\": 670, \"library_items\": 0, \"archive_items\": 1000000, \"object_records\": 109173, \"library_records\": 0, \"archive_records\": 336877}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"artefacts\": 500000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"artefacts\": 1105051, \"objects\": 5051, \"library_items\": 0, \"archive_items\": 1100000, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Derby Museums\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"East Ayrshire Leisure Trust\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"artefacts\": 36000, \"objects\": 36000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"artefacts\": 1000000, \"objects\": 1000000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Groam House Museum\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"artefacts\": 406750, \"objects\": 405000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"artefacts\": 10000, \"objects\": 10000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Hull Museums Collections\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"artefacts\": 1300000, \"objects\": 1300000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"artefacts\": 1500000, \"objects\": 1500000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Liverpool Record Office\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"artefacts\": 220000, \"objects\": 220000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Museums Northhumberland\", \"sector\": \"regional\", \"artefacts\": 25000, \"objects\": 25000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Norfolk Museums Collections\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Northhampton Museums\", \"sector\": \"regional\", \"artefacts\": 44024, \"objects\": 44024, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Northern Ireland Screen\", \"sector\": \"regional\", \"artefacts\": 47, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"artefacts\": 100000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"artefacts\": 50000, \"objects\": 50000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 1489, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"artefacts\": 1000000, \"objects\": 1000000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 1489, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"artefacts\": 100000, \"objects\": 100000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"artefacts\": 9000, \"objects\": 9000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 15, \"library_records\": 0, \"archive_records\": 5}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"artefacts\": 1000000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 16000, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"artefacts\": 100000, \"objects\": 100000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Sheffield Museums\", \"sector\": \"regional\", \"artefacts\": 1000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 1000, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Southampton Cultural Services\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"artefacts\": 108000, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Tyne & Wear Museums\", \"sector\": \"regional\", \"artefacts\": 490107, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 490107, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"artefacts\": 111000, \"objects\": 111000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"artefacts\": 15000, \"objects\": 15000, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"Wiltshire Museum\", \"sector\": \"regional\", \"artefacts\": 126410, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 126410, \"library_records\": 0, \"archive_records\": 0}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"artefacts\": 0, \"objects\": 0, \"library_items\": 0, \"archive_items\": 0, \"object_records\": 0, \"library_records\": 0, \"archive_records\": 0}], \"data-a0c3a5906202575e7b0edb3dafb3606d\": [{\"institution\": \"Aberdeenshire Council Museums\", \"values\": 250000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 250000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Aberdeenshire Council Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-b5b5474dfa8a4af47695f5830e023882\": [{\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Auchindrain Historic Township\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-d5357a5e1134bd5f6e58dc69a328a6e3\": [{\"institution\": \"Barnsley Museums\", \"values\": 711400, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 711400, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Barnsley Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-b916638082d972f147a9303a3313a32d\": [{\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Beamish Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-f5bfe9f58793a903e05c2a65b2156071\": [{\"institution\": \"Birmingham Museums Trust\", \"values\": 800000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 800000, \"calculated\": 800000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 0, \"calculated\": 800000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Birmingham Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-d9d03407b1f46b1f3f1c51fa5f951392\": [{\"institution\": \"Black Country Living Museum\", \"values\": 80000, \"calculated\": 4903, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 80000, \"calculated\": 80000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 0, \"calculated\": 4903, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 0, \"calculated\": 80000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 4903, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Black Country Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-76dcec2fb5eaae1d7b013590cf76ba41\": [{\"institution\": \"Bradford District Museums & Galleries\", \"values\": 837837, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 387837, \"calculated\": 837837, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 450000, \"calculated\": 387837, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Bradford District Museums & Galleries\", \"values\": 0, \"calculated\": 450000, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-2a0dd31c67900b8070beaebb78d8ed2e\": [{\"institution\": \"Bristol Museums\", \"values\": 2000000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 2000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Bristol Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-9b4a1e706b01e369125107582239caf3\": [{\"institution\": \"Colchester and Ipswich Museums\", \"values\": 220000, \"calculated\": 220000, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 0, \"calculated\": 220000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 220000, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Colchester and Ipswich Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-785b146f8faa7252899718eea5a3893d\": [{\"institution\": \"Culture Coventry\", \"values\": 1000000, \"calculated\": 446050, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Culture Coventry\", \"values\": 670, \"calculated\": 1000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Culture Coventry\", \"values\": 0, \"calculated\": 670, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Culture Coventry\", \"values\": 1000000, \"calculated\": 670, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Culture Coventry\", \"values\": 109173, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Culture Coventry\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Culture Coventry\", \"values\": 336877, \"calculated\": 1000000, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-bb8d23a10e4d46a68b6317edd7813d7c\": [{\"institution\": \"Culture Perth and Kinross\", \"values\": 500000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 500000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Culture Perth and Kinross\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-915302f4cc4f0ea05e09ed3fde6ddeea\": [{\"institution\": \"Culture Trust Luton\", \"values\": 1105051, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 5051, \"calculated\": 1105051, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 1100000, \"calculated\": 5051, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Culture Trust Luton\", \"values\": 0, \"calculated\": 1100000, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-ede38ab306edd12d80552566f6f4576a\": [{\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Derby Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-65e09163c56d04c0818fc27644e7dfcf\": [{\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Dumfries and Galloway Council Arts and Museums Service\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-5f93e30645560c866e30c0ed3b6a1335\": [{\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Dundee Heritage Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-dbc54208696341a279acda1094e987fe\": [{\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"East Ayrshire Leisure Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-3621cd5bbd9933a31dd224c77d865e5c\": [{\"institution\": \"Edinburgh Museums\", \"values\": 220000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 220000, \"calculated\": 220000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 0, \"calculated\": 220000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Edinburgh Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-58a3bbdf2d67d395336cc984ab673f78\": [{\"institution\": \"Elgin Museum\", \"values\": 36000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Elgin Museum\", \"values\": 36000, \"calculated\": 36000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Elgin Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Elgin Museum\", \"values\": 0, \"calculated\": 36000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Elgin Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Elgin Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Elgin Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-093b37d40df86d7edfa2ce9bc8e9c833\": [{\"institution\": \"Glasgow Museums\", \"values\": 1000000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Glasgow Museums\", \"values\": 1000000, \"calculated\": 1000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Glasgow Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Glasgow Museums\", \"values\": 0, \"calculated\": 1000000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Glasgow Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Glasgow Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Glasgow Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-be6955d47adc1b72c040cda41fddb9af\": [{\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Groam House Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-c60b3848499adfefb039b887a47bc190\": [{\"institution\": \"Heritage Doncaster\", \"values\": 406750, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 405000, \"calculated\": 406750, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 0, \"calculated\": 405000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Heritage Doncaster\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-0d22b11ffac65d9ebbfd3e1621dc454d\": [{\"institution\": \"Highland Folk Museum\", \"values\": 10000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 10000, \"calculated\": 10000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 0, \"calculated\": 10000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Highland Folk Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-384f9cbe2052f29e2114dfe6b4491606\": [{\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Hull Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-947628e383266059d87eef2445a20906\": [{\"institution\": \"Leeds Museums & Galleries\", \"values\": 1300000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 1300000, \"calculated\": 1300000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 0, \"calculated\": 1300000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Leeds Museums & Galleries\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-71a94014dd597d52fc4a6c14164e098b\": [{\"institution\": \"Leicester Museums\", \"values\": 1500000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Leicester Museums\", \"values\": 1500000, \"calculated\": 1500000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Leicester Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Leicester Museums\", \"values\": 0, \"calculated\": 1500000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Leicester Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Leicester Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Leicester Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-443c19814bc117562decfaa958bc9c91\": [{\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Leicestershire County Council Museum Servive\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-1f9377a945d0ca94efa301726735c476\": [{\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Liverpool Record Office\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-2d7da1f275b69cdd2d19748e543d119e\": [{\"institution\": \"Manchester Art Gallery\", \"values\": 50000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 50000, \"calculated\": 50000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 0, \"calculated\": 50000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Manchester Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-97029f92aa31b40a8ea6f121b240981c\": [{\"institution\": \"Museums Northhumberland\", \"values\": 25000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 25000, \"calculated\": 25000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 0, \"calculated\": 25000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Museums Northhumberland\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-a1c0f229e6da03da709fedc3bb6838c3\": [{\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Norfolk Museums Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-484fff9710d8c12db84937de628207e9\": [{\"institution\": \"Northern Ireland Screen\", \"values\": 47, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 47, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Northern Ireland Screen\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-ba7d2f6d2013323968538aa6dc8a244d\": [{\"institution\": \"Northhampton Museums\", \"values\": 44024, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Northhampton Museums\", \"values\": 44024, \"calculated\": 44024, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Northhampton Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Northhampton Museums\", \"values\": 0, \"calculated\": 44024, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Northhampton Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Northhampton Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Northhampton Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-b729f1bec6e2f7b6276caa02967cb4de\": [{\"institution\": \"Orkney Museums\", \"values\": 100000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 100000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Orkney Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-828d08fa9ee5059dc48e2bd092adbc76\": [{\"institution\": \"Poole Museums\", \"values\": 50000, \"calculated\": 1489, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Poole Museums\", \"values\": 50000, \"calculated\": 50000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Poole Museums\", \"values\": 0, \"calculated\": 1489, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Poole Museums\", \"values\": 0, \"calculated\": 50000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Poole Museums\", \"values\": 1489, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Poole Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Poole Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-235c8cb6ef3356c26a1a6d9e7dc6848e\": [{\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 1000000, \"calculated\": 1489, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 1000000, \"calculated\": 1000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 0, \"calculated\": 1489, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 0, \"calculated\": 1000000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 1489, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Potteries Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-110567b3995a8bc6bbc9bfb7ff145ef8\": [{\"institution\": \"Preston Park Museum & Grounds\", \"values\": 100000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 100000, \"calculated\": 100000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 0, \"calculated\": 100000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Preston Park Museum & Grounds\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-eefda7e81b8ac4195cafc4a1aaea1bc6\": [{\"institution\": \"Ripon Museums\", \"values\": 9000, \"calculated\": 20, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Ripon Museums\", \"values\": 9000, \"calculated\": 9000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Ripon Museums\", \"values\": 0, \"calculated\": 15, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Ripon Museums\", \"values\": 0, \"calculated\": 9000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Ripon Museums\", \"values\": 15, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Ripon Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Ripon Museums\", \"values\": 5, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-74aa0f112b2d1a1baaf40e45a380e746\": [{\"institution\": \"Royal Albert Memorial Museum\", \"values\": 1000000, \"calculated\": 16000, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 0, \"calculated\": 1000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 16000, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Royal Albert Memorial Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-a5aaaa265e3df665d51be45d156a2a48\": [{\"institution\": \"Salisbury Museum\", \"values\": 100000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Salisbury Museum\", \"values\": 100000, \"calculated\": 100000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Salisbury Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Salisbury Museum\", \"values\": 0, \"calculated\": 100000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Salisbury Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Salisbury Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Salisbury Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-dc07f8c4788c74b8ff03a80bf17d88a3\": [{\"institution\": \"Sheffield Museums\", \"values\": 1000, \"calculated\": 1000, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Sheffield Museums\", \"values\": 0, \"calculated\": 1000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Sheffield Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Sheffield Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Sheffield Museums\", \"values\": 1000, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Sheffield Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Sheffield Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-d459015b366d2fe7a456263e23487587\": [{\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Southampton Cultural Services\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-9a9ef6422b470d5696178918f738c0e3\": [{\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"St Helens Borough Council\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-d9ada58a94eeaadd9ce6687c07c4749e\": [{\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Staffordshire Archive and Heritage\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-2bc0a552153b8512b0caf22caca6c86f\": [{\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 108000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 108000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-80f313c6a69783561cd00b6653936944\": [{\"institution\": \"Thackray Museum of Medicine\", \"values\": 75000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 75000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Thackray Museum of Medicine\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-5049faf841d297c7e57c4b180dc2d53d\": [{\"institution\": \"The Box Plymouth\", \"values\": 21691, \"calculated\": 21691, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"The Box Plymouth\", \"values\": 0, \"calculated\": 21691, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"The Box Plymouth\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"The Box Plymouth\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"The Box Plymouth\", \"values\": 21691, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"The Box Plymouth\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"The Box Plymouth\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-2a00d8a208e7b67639d2227c559ee6c7\": [{\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 1000000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 1000000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-f1ac0355d9fd1e5f5117e0aadc01e6c8\": [{\"institution\": \"Tyne & Wear Museums\", \"values\": 490107, \"calculated\": 490107, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 0, \"calculated\": 490107, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 490107, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Tyne & Wear Museums\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-a78afe279d1bcb712a267e97983cc715\": [{\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Vindolanda Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-73cd7e6866fce1000c26a4de461041e1\": [{\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 111000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 111000, \"calculated\": 111000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 0, \"calculated\": 111000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-f733beb95f73991a41f2f8b7ee97ea83\": [{\"institution\": \"Watts Gallery\", \"values\": 12541, \"calculated\": 12541, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Watts Gallery\", \"values\": 0, \"calculated\": 12541, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Watts Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Watts Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Watts Gallery\", \"values\": 7756, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Watts Gallery\", \"values\": 4117, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Watts Gallery\", \"values\": 668, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-573e8c930b90032a01373ee701ad0eae\": [{\"institution\": \"Weald and Downland Living Museum\", \"values\": 15000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 15000, \"calculated\": 15000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 0, \"calculated\": 15000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Weald and Downland Living Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-147d310e2f3cfa938fe98e5f75acee5e\": [{\"institution\": \"William Morris Gallery\", \"values\": 10000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"William Morris Gallery\", \"values\": 10000, \"calculated\": 10000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"William Morris Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"William Morris Gallery\", \"values\": 0, \"calculated\": 10000, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"William Morris Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"William Morris Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"William Morris Gallery\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-fdec4411ade052e269e7eaa77eae6250\": [{\"institution\": \"Wiltshire Museum\", \"values\": 126410, \"calculated\": 126410, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 0, \"calculated\": 126410, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 126410, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Wiltshire Museum\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-9bb7dd6cba5e392e8a34c99026b2d188\": [{\"institution\": \"Wordsworth Museum Collection\", \"values\": 68000, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 68000, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"Wordsworth Museum Collection\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}], \"data-8efa0851e692b95effe838febd00f85b\": [{\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Artefacts\", \"labels_calculated\": \"Artefacts Catalogued\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Objects\", \"labels_calculated\": \"Artefacts\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Items\", \"labels_calculated\": \"Objects Catalogued\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Items/Collections\", \"labels_calculated\": \"Objects\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Museum Records\", \"labels_calculated\": \"Library Items Catalogued\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Library Records\", \"labels_calculated\": \"Library Items\"}, {\"institution\": \"York Museums Trust\", \"values\": 0, \"calculated\": 0, \"labels\": \"Archive Records\", \"labels_calculated\": \"Archive Items\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.VConcatChart(...)"
      ]
     },
     "execution_count": 2,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "row_count = 0\n",
    "row_graphs = []\n",
    "grid_graphs = []\n",
    "\n",
    "for i, institution in regional_institutions_df.sort_values(by=[\"institution\"]).iterrows():\n",
    "    institution_name = institution[\"institution\"]\n",
    "    title = alt.TitleParams(institution_name, anchor='middle')\n",
    "    row_df = pd.DataFrame(\n",
    "       {\"institution\": institution_name,\n",
    "        \"values\": [\n",
    "             institution[\"artefacts\"],\n",
    "            institution[\"objects\"], institution[\"library_items\"], institution[\"archive_items\"],\n",
    "            institution[\"object_records\"], institution[\"library_records\"], institution[\"archive_records\"]],\n",
    "       \"calculated\": [\n",
    "            min(institution[\"object_records\"] + institution[\"library_records\"] + institution[\"archive_records\"], institution[\"artefacts\"]),\n",
    "            institution[\"artefacts\"],\n",
    "            min(institution[\"object_records\"], institution[\"objects\"]), institution[\"objects\"],\n",
    "            min(institution[\"library_records\"], institution[\"library_items\"]), institution[\"library_items\"],\n",
    "         institution[\"archive_items\"] ],\n",
    "            \"labels\": [\"Artefacts\", \n",
    "                                  \"Museum Objects\", \n",
    "                                  \"Library Items\",\n",
    "                                  \"Archive Items/Collections\", \n",
    "                                  \"Museum Records\", \n",
    "                                  \"Library Records\", \"Archive Records\"],\n",
    "            \"labels_calculated\": [ \"Artefacts Catalogued\", \"Artefacts\", \"Objects Catalogued\", \"Objects\",\n",
    "                                  \"Library Items Catalogued\", \"Library Items\",\n",
    "                                   \"Archive Items\"]\n",
    "            })\n",
    "\n",
    "    # Ring gives summary of cataloguing progress\n",
    "    #ring = alt.Chart(row_df).mark_arc(innerRadius=90, outerRadius=100).encode(\n",
    "    #  color=\"labels_calculated:N\",\n",
    "    #  theta=\"calculated\",\n",
    "    #)\n",
    "\n",
    "    if institution[\"artefacts\"] > 0:\n",
    "     catalogued_records =  institution[\"object_records\"] + institution[\"library_records\"] + institution[\"archive_records\"]\n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"artefacts\"], 1) * 2.09\n",
    "         ring1_complete = alt.Chart().mark_arc(\n",
    "             tooltip=f'Catalogued Artefacts: {catalogued_records}',\n",
    "             innerRadius=90, outerRadius=100,theta=0,color=\"gold\", \n",
    "                                theta2=catalogued_proportion - 0.02)\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=catalogued_proportion,color=\"#9ecae1\", \n",
    "                                                  theta2=2.07,\n",
    "                                                  tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "         else:\n",
    "           ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"grey\", theta2=0)\n",
    "     else:\n",
    "        ring1_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"#9ecae1\", theta2=0)\n",
    "        ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,theta2=2.07,color=\"#9ecae1\",\n",
    "                                               tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "    else:\n",
    "      ring1_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,color=\"grey\", theta2=0)\n",
    "      ring1_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=0,theta2=2.07,color=\"grey\",\n",
    "                                             tooltip=f'Total Artefacts: {institution[\"artefacts\"]}')\n",
    "\n",
    "\n",
    "    if institution[\"objects\"] > 0:\n",
    "     catalogued_records =  institution[\"object_records\"] \n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"objects\"], 1) * 2.09\n",
    "         ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"gold\",\n",
    "                                               theta2=2.09 + catalogued_proportion - 0.02, \n",
    "                                                            tooltip=f'Catalogued Objects: {catalogued_records}')\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09+ catalogued_proportion,color=\"#fd8d3c\", \n",
    "                                                  theta2=4.16, tooltip=f'Total Objects: {institution[\"objects\"]}')\n",
    "     else:\n",
    "        ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"#fd8d3c\", theta2=2.09)\n",
    "        ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"#fd8d3c\",\n",
    "                                               tooltip=f'Total Objects: {institution[\"objects\"]}')\n",
    "    else:\n",
    "      ring2_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,color=\"grey\", theta2=2.09)\n",
    "      ring2_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"grey\", \n",
    "                                             tooltip=f'Total Objects: {institution[\"objects\"]}')  \n",
    "        \n",
    "#    ring2 = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=2.09,theta2=4.16,color=\"gray\")\n",
    "\n",
    "    if institution[\"library_items\"] > 0:\n",
    "     catalogued_records = institution[\"library_records\"] \n",
    "     if catalogued_records > 0:\n",
    "         catalogued_proportion = min(catalogued_records / institution[\"library_items\"], 1) * 2.09\n",
    "         ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,\n",
    "                                               theta=4.18,color=\"gold\", \n",
    "                                               tooltip=f'Catalogued Library Items: {catalogued_records}',\n",
    "                                               theta2=4.18 + catalogued_proportion - 0.02)\n",
    "         if catalogued_proportion < 2.09:\n",
    "           ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18+catalogued_proportion,color=\"#c6dbef\", \n",
    "                                                  theta2=6.27, tooltip=f'Total Library Items: {institution[\"library_items\"]}')\n",
    "     else:\n",
    "        ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,color=\"#c6dbef\", theta2=4.18)\n",
    "        ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,\n",
    "                                               color=\"#c6dbef\", tooltip=f'Total Library Items: {institution[\"library_items\"]}')\n",
    "    else:\n",
    "      ring3_complete = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,color=\"grey\", theta2=4.18)\n",
    "      ring3_remaining = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,color=\"grey\",\n",
    "                                             tooltip=f'Total Library Items: {institution[\"library_items\"]}') \n",
    "        \n",
    "#    ring3 = alt.Chart().mark_arc(innerRadius=90, outerRadius=100,theta=4.18,theta2=6.27,color=\"orange\")\n",
    "\n",
    "    # Petal graph ? gives summary of size of instution collections\n",
    "    base1 = alt.Chart(row_df, width=160, title=title).encode(\n",
    "      alt.Theta(\"values:Q\").stack(True),\n",
    "      alt.Radius(\"values\").scale(type=\"sqrt\", zero=True, rangeMin=20),\n",
    "      tooltip='labels:N',\n",
    "      color=alt.Color(\"labels:N\", sort=\"ascending\").legend(orient=\"top\", titleOrient=\"left\").scale(scheme=\"category20c\"),\n",
    "    ).properties(\n",
    "      width=200,\n",
    "      height=200\n",
    "    )\n",
    "\n",
    "#    text_complete = alt.Chart().mark_text().encode(\n",
    "#        text=f\"{institution['artefacts']}:Q\")\n",
    "#        text=alt.Text(institution[\"artefacts\"]), color=\"gold\").properties(width=100)\n",
    "    \n",
    "    petal_marks = base1.mark_arc(innerRadius=45, outerRadius=60, cornerRadius=5, \n",
    "                                 stroke=\"#fff\")\n",
    "    \n",
    "#    petal_text = base1.mark_text(radiusOffset=58).encode(text=\"values:Q\")\n",
    "#    alt.FieldGTPredicate(\"values\", 0), alt.Text('values:Q'), alt.value(''))\n",
    "\n",
    "    petal_text = base1.mark_text(radiusOffset=58).encode(\n",
    "        text=alt.condition(alt.FieldGTPredicate(\"values\", 0), alt.Text('values:Q'), alt.value('')))\n",
    "\n",
    "    # Bar at bottom indicates proportion of national collection this institution has\n",
    "    bar = alt.Chart(regional_institutions_df, height=20, width=200).mark_bar().encode(\n",
    "      alt.X(\"artefacts\").title(\"Proportion of National Collection\"),\n",
    "      tooltip='artefacts',\n",
    "      color=alt.condition(\n",
    "        alt.FieldOneOfPredicate('institution', [institution_name]),\n",
    "        alt.value('gold'),     \n",
    "        alt.value('white')     \n",
    "      )\n",
    "    )\n",
    "    \n",
    "    institution_graph = alt.vconcat((petal_marks + petal_text + ring1_complete + \n",
    "                                     ring1_remaining + ring2_complete + ring2_remaining +\n",
    "                                     ring3_remaining + ring3_complete), bar).resolve_scale(theta='independent')\n",
    "    if row_count < 3:\n",
    "        row_graphs.append(institution_graph)\n",
    "        row_count += 1\n",
    "    else:   \n",
    "        row_graphs.append(institution_graph)\n",
    "        grid_graphs.append(\n",
    "            alt.hconcat(*row_graphs, spacing=40).resolve_scale(theta='shared'))\n",
    "        row_count = 0\n",
    "        row_graphs = []\n",
    "\n",
    "if row_count > 0:\n",
    "    grid_graphs.append(\n",
    "            alt.hconcat(*row_graphs, spacing=40).resolve_scale(theta='shared'))\n",
    "\n",
    "alt.vconcat(*grid_graphs).configure(numberFormat='.2s')\n",
    "#alt.hconcat(*row_graphs, spacing=40).configure(numberFormat='.2s').resolve_scale(theta='shared')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "488bd315-b12b-4503-b226-a864ba934206",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.18"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
